==> haskell-xml-conduit-1.9.1.4-143-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xml-conduit
version:              1.9.1.4
visibility:           public
id:                   xml-conduit-1.9.1.4-AWUHrHEyod1C1UJeqVfDQt
key:                  xml-conduit-1.9.1.4-AWUHrHEyod1C1UJeqVfDQt
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>

stability:            Stable
homepage:             http://github.com/snoyberg/xml
synopsis:
    Pure-Haskell utilities for dealing with XML with the conduit package.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.

category:             XML, Conduit
abi:                  2cfb302e43130d7cf13005fc87c8e35b
exposed:              True
exposed-modules:
    Text.XML Text.XML.Cursor Text.XML.Cursor.Generic
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved

hidden-modules:       Text.XML.Stream.Token
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xml-conduit-1.9.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xml-conduit-1.9.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xml-conduit-1.9.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-conduit
hs-libraries:         HSxml-conduit-1.9.1.4-AWUHrHEyod1C1UJeqVfDQt
depends:
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    blaze-html-0.9.2.0-5pCa6Zd2ytCBxKPCiAVcIx
    blaze-markup-0.8.3.0-JJ5r8tycCxXJkM0kXa0ha9 bytestring-0.11.5.3
    conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
    conduit-extra-1.3.8-Dg42smPzbiF4Nemzj9bTg6 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    resourcet-1.2.6-7GW6wEwAkCf499WYv26LMs text-2.0.2
    transformers-0.6.1.0 xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau

haddock-interfaces:   /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html:         /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-conduit-1.9.1.4-145-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xml-conduit
version:              1.9.1.4
visibility:           public
id:                   xml-conduit-1.9.1.4-6YUKnRkiQ5NBAoTmcKCArn
key:                  xml-conduit-1.9.1.4-6YUKnRkiQ5NBAoTmcKCArn
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>

stability:            Stable
homepage:             http://github.com/snoyberg/xml
synopsis:
    Pure-Haskell utilities for dealing with XML with the conduit package.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.

category:             XML, Conduit
abi:                  e9faafaa15e49dca894705f958540b0e
exposed:              True
exposed-modules:
    Text.XML Text.XML.Cursor Text.XML.Cursor.Generic
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved

hidden-modules:       Text.XML.Stream.Token
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xml-conduit-1.9.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xml-conduit-1.9.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xml-conduit-1.9.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-conduit
hs-libraries:         HSxml-conduit-1.9.1.4-6YUKnRkiQ5NBAoTmcKCArn
depends:
    attoparsec-0.14.4-8hLS1m777hPFjiaInp95BL base-4.18.2.1
    blaze-html-0.9.2.0-AqjQr4Ps51QD51ybemU3ZY
    blaze-markup-0.8.3.0-K7wUMOM5SyIFeEdepQMdjc bytestring-0.11.5.3
    conduit-1.3.6.1-CwUx671uWmDAcHwxI0YYDy
    conduit-extra-1.3.8-GHF5wYhQp30HUaLAtCbs0G containers-0.6.7
    data-default-0.7.1.3-Ihbp7WFUy146w4K1utdfXl deepseq-1.4.8.1
    resourcet-1.2.6-JtO0n9rtgTt543EMYn7K77 text-2.0.2
    transformers-0.6.1.0 xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau

haddock-interfaces:   /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html:         /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
